==> dhall-docs-1.0.12-107-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-docs
version:              1.0.12
visibility:           public
id:                   dhall-docs-1.0.12-KhSIYLpswcPElPf4DhNpve
key:                  dhall-docs-1.0.12-KhSIYLpswcPElPf4DhNpve
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  a61b7f061cdfe25d2d49dcd8fc5a5468
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-docs-1.0.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-docs-1.0.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-docs-1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.12-KhSIYLpswcPElPf4DhNpve
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-5J7tyLLyUk5BSrxgZ0XvOi
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-3VpgZnrNkchINpWq9aX9Hh
    dhall-1.42.2-IxPLfiNYZuQF4e0YQTqORz directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    lens-family-core-2.1.3-Ij4qXDXH4U49wX5TL83dlV
    lucid-2.11.20250303-8iYNzjVkl85947kE9iW2Gk
    megaparsec-9.7.0-7JToewzpODIKYsxdMWTRd1
    mmark-0.0.7.6-Ja8Q6ikOl41J3azYt9KMx5 mtl-2.2.2
    optparse-applicative-0.18.1.0-FoUSxzMBUR5IeTMTUEotqz
    path-0.9.5-As79PD9C9E7RizQ5qohNB
    path-io-1.8.2-IEqVdQejEEnJ7kgeZFkzV1
    prettyprinter-1.7.1-K25tjwTKXuP4KBelsyCegB text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-docs-1.0.12-108-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-docs
version:              1.0.12
visibility:           public
id:                   dhall-docs-1.0.12-CLJllpHdKxYF6tCM5mGj1n
key:                  dhall-docs-1.0.12-CLJllpHdKxYF6tCM5mGj1n
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  a374d31b0ee368c911f67571eb2a4395
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-docs-1.0.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-docs-1.0.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-docs-1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.12-CLJllpHdKxYF6tCM5mGj1n
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-5J7tyLLyUk5BSrxgZ0XvOi
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-3VpgZnrNkchINpWq9aX9Hh
    dhall-1.42.2-4137QB3AcHuIe0VWFaYXsU directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    lens-family-core-2.1.3-Ij4qXDXH4U49wX5TL83dlV
    lucid-2.11.20250303-8iYNzjVkl85947kE9iW2Gk
    megaparsec-9.7.0-7JToewzpODIKYsxdMWTRd1
    mmark-0.0.7.6-Ja8Q6ikOl41J3azYt9KMx5 mtl-2.2.2
    optparse-applicative-0.18.1.0-FoUSxzMBUR5IeTMTUEotqz
    path-0.9.5-As79PD9C9E7RizQ5qohNB
    path-io-1.8.2-IEqVdQejEEnJ7kgeZFkzV1
    prettyprinter-1.7.1-K25tjwTKXuP4KBelsyCegB text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
